﻿© Fluke Corporation. All Rights Reserved.                   MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Get Fixed Standard Certified Value
DATE:                  2004-11-17
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       188
=============================================================================
#
#  Procedure Author:
#        DAC, DFM
#
#  Model(s) Covered:
#        Various
#
#  Compatibility:
#        MET/CAL or 5500/CAL 7.1 or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
#  This procedure is intended to be used to retrieve and pass the value of any
#  type of fixed standard, for example, resistors, capacitors, etc. It is a
#  derivative of "Sub Get Fluke 742A-series Certified Value (ini)" except it
#  allows not only the value of the unit to be specified, but also the type of
#  unit, i.e., Ohms, Farads, Henries, etc. Of course, an accompanying data
#  (ini) file must be created to contain the data, similar to the following:
#
#  Example file contents, "9230a-15.ini", where the first line reflects the
#  fixed standard's asset number; the rest is obvious.
#
#        [Sample-Guildline_9230A-15]
#        Nominal_Value   = 0.5
#        Certified_Value = 0.4999995
#        Cal_Date        = 16-Nov-04
#
#  In use, the following example procedure lines might be used:
#
#    1.001  STD          Guildline 9320A-15
#
#  Set Instrument Name to STD name.
#    1.002  MATH         MEM2 = PUT("Instrument_Name", "Guildline 9320A-15")
#
#  Set Nominal value to 0.5 Ohm
#    1.003  MATH         MEM2 = PUT("Nominal_Value", 0.5)
#
#  Set type of units
#    1.003  MATH         MEM2 = PUT("Units", "Ohms")
#
#  Set name of data file
#    1.004  MATH         MEM2 = PUT("Data_File", "9230a.ini")
#
#  Set notification flag to true.
#    1.005  MATH         MEM2 = PUT("Validate", 1)
#
#    1.006  CALL         Sub Get Fixed Standard Certified Value (ini)
#
#  The subprocedure returns the certified value in MEM.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Get the path to data file.  Parameters in the MET/CAL initialization file
# determine where MET/CAL will search for the data file.

# Use Current Working Directory (CWD) if specified.
  1.001  MATH         MEM2 = INI("Startup", "user_cwd")

# Otherwise use User Program Director, if specified.
  1.002  IF           ZCMP(MEM2, "")
  1.003  MATH         MEM2 = INI("Startup", "user_prog_dir")
  1.004  ENDIF

# Get data file name.
  1.005  MATH         S[20] =GET("Data_File")

# Build path to data file.
  1.006  MATH         S[21] = MEM2 & "\\" & S[20]

# Get the configured Instrument Name of the device.
  1.007  MATH         S[22] = GET("Instrument_Name")

# Get the asset assigned to the configured device.
  1.008  MATH         S[23] = ASSET(S[22])

# Get type of units name.
  1.009  MATH         S[24] =GET("Units")

# Initialize error flag to false.
  1.010  MATH         MEM2 = PUT("Error", 0)

  1.011  IF           ZCMPI(S[23], "")
  1.012  DISP         No asset number specified for configured instrument:
  1.012  DISP         [S22].
  1.012  DISP
  1.012  DISP         You must terminate the procedure, then press F12 or
  1.012  DISP         select Configure->Instruments to specify the asset
  1.012  DISP         number of [S22].
  1.013  MATH         MEM2 = PUT("Error", 1)
  1.014  END
  1.015  ENDIF

# Get nominal value associated with the asset number in initialization file.
  1.016  MATH         MEM2 = RIF(S[21], S[23], "Nominal_Value")

# Make sure lookup suceeded.
  1.017  IF           ZCMP(MEM2, "")
  1.018  HEAD         FATAL ERROR
  1.019  DISP         File:       [S21]
  1.019  DISP         Section:    [91][S23][93]
  1.019  DISP         Parameter:  Nominal_Value = ...
  1.019  DISP
  1.019  DISP         Cannot find section and/or parameter name!
  1.020  MATH         MEM2 = PUT("Error", 1)
  1.021  END
  1.022  ENDIF

  1.023  MATH         L[1] = MEM2
  1.024  MATH         L[2] = GET("Nominal_Value")

# Make sure nominal value in initialization file agrees with specified value.
  1.025  IF           L[1] != L[2]
  1.026  HEAD         FATAL ERROR
  1.027  DISP         File:       [S21]
  1.027  DISP         Section:    [91][S22][93]
  1.027  DISP         Parameter:  Nominal_Value = [L1] [S24]
  1.027  DISP
  1.027  DISP         Calling procedure specified [L2] [S24]!
  1.028  MATH         MEM2 = PUT("Error", 1)
  1.029  END
  1.030  ENDIF

# Get certified value associated with the asset number in initialization file.
  1.031  MATH         MEM = RIF(S[21], S[23], "Certified_Value")

# Make sure lookup suceeded.
  1.032  IF           ZCMP(L[3], "")
  1.033  HEAD         FATAL ERROR
  1.034  DISP         File:       [S21]
  1.034  DISP         Section:    [91][S23][93]
  1.034  DISP         Parameter:  Certified_Value = ...
  1.034  DISP
  1.034  DISP         Cannot find section and/or parameter name!
  1.035  MATH         MEM2 = PUT("Error", 1)
  1.036  END
  1.037  ENDIF

# Display the data to the operator if the validate flag is true.
  1.038  IF           GET("Validate")
  1.039  OPBR         The certified value for [S22],
  1.039  OPBR         Asset "[S23]" is [MEM] [S24].
  1.039  OPBR
  1.039  OPBR         Is this correct?

  1.040  IF           MEM1 < 0
  1.041  DISP         Contact the MET/CAL Administrator to update:
  1.041  DISP         [S21].
  1.042  MATH         MEM2 = PUT("Error", 1)
  1.043  END
  1.044  ENDIF

  1.045  ENDIF

  1.046  END
