﻿Copyright (c) (2016) Fluke Corporation                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Meterman 38XR Get Reading RS-232
DATE:                  2017-02-13 14:35:54
AUTHOR:                Fluke
REVISION:              $Revision: 18287 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       205
=============================================================================
#
#  Procedure Author:  DAC
#
#  Model(s) Covered:  38XR
#
#  Additional Equipment Required:
#                     None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
#  Calling procedure must contain the following line:
# 1.001  PORT         [P9600,N,8,1,N][TERM LF]
#
#  The 38XR serial response is 15 bytes (13 characters <CR><LF>)
#
#  Register usage:
#
#    S[1]   Function Code          Bytes  1 & 2
#    S[3]   Reading or Error Code  Bytes  3, 4, 5 & 6
#    S[9]   Range Code             Byte   9
#    S[10]  Amps function          Byte  10
#    S[11]  Peak status            Byte  11
#    S[12]  RFLAG_H push button    Byte  12
#    S[13]  RFLAG_L push button    Byte  13
#
#    MEM    Reading
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# 1. Clear input buffer.
# 2. Read 1st response, CR, LF and throwaway.
# 3. Read next response and store in MEM2.

  1.001  PORT         [CLR][I!][I$]

# Get function code substring.
  1.002  MATH         S[1]  = SUB(MEM2,  1, 2)
# Get the reading/error code substring.
  1.003  MATH         S[3]  = SUB(MEM2,  3, 4)
# Get the range code substring.
  1.004  MATH         S[9]  = SUB(MEM2,  9, 1)
# Get the Amps function (qualifier) code substring.
  1.005  MATH         S[10] = SUB(MEM2, 10, 1)
# Get the Peak status substring.
  1.006  MATH         S[11] = SUB(MEM2, 11, 1)
# Get the RFLAG_H Push Button setting substring.
  1.007  MATH         S[12] = SUB(MEM2, 12, 1)
# Get the RFLAG_L Push Button setting substring.
  1.008  MATH         S[13] = SUB(MEM2, 13, 1)

# Check for overload condition.  If so, set reading to 9.999E+99.
  1.009  IF           ZCMP(S[3], "B0DD")
# Check for input jack error.
  1.010  MATH         MEM = 9.999E+99
  1.011  ELSEIF       ZCMP(S[3], "BAAB")
  1.012  DISP         Input jack error!  Check connections.
  1.013  MATH         MEM = -9.999E+99
  1.014  ELSE
  1.015  MATH         MEM = S[3]

# Scale reading if necessary.

# dBm
  1.016  IF           ZCMP(S[13], "4") || ZCMP(S[13], "5")

  1.017  MATH         MEM = MEM / 100

# VAC, VDC, & VAC+DC
  1.018  ELSEIF       ZCMP(S[1], "10") || ZCMP(S[1], "0C")

  1.019  IF           ZCMP(S[9], "0")
  1.020  MATH         MEM = MEM / 10E+3
  1.021  ELSEIF       ZCMP(S[9], "1")
  1.022  MATH         MEM = MEM / 1E+3
  1.023  ELSEIF       ZCMP(S[9], "2")
  1.024  MATH         MEM = MEM / 100
  1.025  ELSEIF       ZCMP(S[9], "3")
  1.026  MATH         MEM = MEM / 10
  1.027  ENDIF

# Diode
  1.028  ELSEIF       ZCMP(S[1], "04")

  1.029  MATH         MEM = MEM / 1E+3

# Ohms
  1.030  ELSEIF       ZCMP(S[1], "08")

  1.031  IF           ZCMP(S[9], "0")
  1.032  MATH         MEM = MEM * 10E+3
  1.033  ELSEIF       ZCMP(S[9], "1")
  1.034  MATH         MEM = MEM * 1E+3
  1.035  ELSEIF       ZCMP(S[9], "2")
  1.036  MATH         MEM = MEM * 100
  1.037  ELSEIF       ZCMP(S[9], "3")
  1.038  MATH         MEM = MEM * 10
  1.039  ELSEIF       ZCMP(S[9], "5")
  1.040  MATH         MEM = MEM / 10
  1.041  ENDIF

# µA
  1.042  ELSEIF       ZCMP(S[1], "07")

  1.043  IF           ZCMP(S[9], "0")
  1.044  MATH         MEM = MEM * 10E-9
  1.045  ELSEIF       ZCMP(S[9], "1")
  1.046  MATH         MEM = MEM * 100E-9
  1.047  ENDIF

# mA
  1.048  ELSEIF       ZCMP(S[1], "0E")

  1.049  IF           ZCMP(S[9], "0")
  1.050  MATH         MEM = MEM * 1E-6
  1.051  ELSEIF       ZCMP(S[9], "1")
  1.052  MATH         MEM = MEM * 10E-6
  1.053  ELSEIF       ZCMP(S[9], "2")
  1.054  MATH         MEM = MEM * 100E-6
  1.055  ENDIF

# 10A
  1.056  ELSEIF       ZCMP(S[1], "0A")
  1.057  MATH         MEM = MEM / 1E+3

# Hz
  1.058  ELSEIF       ZCMP(S[1], "0F")

  1.059  IF           ZCMP(S[12], "B")
  1.060  MATH         MEM = MEM / 100
  1.061  ELSE

  1.062  IF           ZCMP(S[9], "0")
  1.063  MATH         MEM = MEM / 100
  1.064  ELSEIF       ZCMP(S[9], "1")
  1.065  MATH         MEM = MEM / 10
  1.066  ELSEIF       ZCMP(S[9], "3")
  1.067  MATH         MEM = MEM * 10
  1.068  ELSEIF       ZCMP(S[9], "4")
  1.069  MATH         MEM = MEM * 100
  1.070  ELSEIF       ZCMP(S[9], "5")
  1.071  MATH         MEM = MEM * 1E+3
  1.072  ELSEIF       ZCMP(S[9], "6")
  1.073  MATH         MEM = MEM * 10E+3
  1.074  ENDIF

  1.075  ENDIF

# Farads
  1.076  ELSEIF       ZCMP(S[1], "0B")

  1.077  IF           ZCMP(S[9], "0")
  1.078  MATH         MEM = MEM * 10E-12
  1.079  ELSEIF       ZCMP(S[9], "1")
  1.080  MATH         MEM = MEM * 100E-12
  1.081  ELSEIF       ZCMP(S[9], "2")
  1.082  MATH         MEM = MEM * 1E-9
  1.083  ELSEIF       ZCMP(S[9], "3")
  1.084  MATH         MEM = MEM * 10E-9
  1.085  ELSEIF       ZCMP(S[9], "4")
  1.086  MATH         MEM = MEM * 100E-9
  1.087  ENDIF

# 4-20mADC
  1.088  ELSEIF       ZCMP(S[1], "03")

  1.089  MATH         MEM = MEM / 100

  1.090  ENDIF

# Negate reading if necessary.

# Check Peak status for negative peak.
  1.091  MATH         L[1] =  ZCMP(S[11], "3") || ZCMP(S[11], "B")

# Check RFLAG_L for "Negative reading" or "-dBm".
  1.092  MATH         L[1] = L[1] || ZCMP(S[13], "1") || ZCMP(S[13], "5")

  1.093  IF           L[1]
  1.094  MATH         MEM = -1 * MEM
  1.095  ENDIF

  1.096  ENDIF

  1.097  END
